TIRSPosition

Struct TIRSPosition 

pub struct TIRSPosition { /* private fields */ }

Implementations

Source

impl TIRSPosition

pub fn new(x: f64, y: f64, z: f64, epoch: TT) -> Self

pub fn x(&self) -> f64

pub fn y(&self) -> f64

pub fn z(&self) -> f64

pub fn epoch(&self) -> TT

pub fn position_vector(&self) -> Vector3

pub fn from_position_vector(pos: Vector3, epoch: TT) -> Self

pub fn geocentric_distance(&self) -> f64

pub fn distance_to(&self, other: &Self) -> f64

pub fn compute_delta_t(epoch: &TT, eop: &EopParameters) -> CoordResult<f64>

Computes ΔT (TT - UT1) using EOP parameters.

EOP Freshness Check

Rejects EOP data >1 day from the target epoch. This ensures UT1-UTC is current, as Earth’s rotation is irregular. For sparse datasets, consider:

  • Using an interpolator to fill gaps (see EopManager)
  • Relaxing this check if lower precision is acceptable (modify this threshold)
  • Pre-fetching/caching EOP data for your observation window

Typical use cases handle this via interpolation, so sparse raw data should be rare.

pub fn to_itrs( &self, epoch: &TT, eop: &EopParameters, ) -> CoordResult<ITRSPosition>

pub fn from_itrs( itrs: &ITRSPosition, epoch: &TT, eop: &EopParameters, ) -> CoordResult<Self>

pub fn from_cirs( cirs_vec: Vector3, epoch: &TT, eop: &EopParameters, ) -> CoordResult<Self>

pub fn to_cirs(&self, eop: &EopParameters) -> CoordResult<CIRSPosition>